@@ -13,7 +13,6 @@
 #include <QQmlApplicationEngine>
 #include <QQuickWidget>
 #include <QQuickItem>
-#include <KDeclarative/KDeclarative>
 #include <QMetaMethod>
 #include <QVBoxLayout>
 #include <KLocalizedString>
@@ -23,13 +22,14 @@
 #include <QDBusInterface>
 #include <QDBusConnection>
 
+#include <KDeclarative/KDeclarative>
+#include <KLocalizedContext>
 #include <KMessageBox>
 #include <KPluginFactory>
 #include <KSambaShare>
 #include <KSambaShareData>
 #include <KService>
 #include <KIO/ApplicationLauncherJob>
-#include <KCoreAddons>
 
 #include "model.h"
 #include "usermanager.h"
@@ -195,11 +195,11 @@ SambaUserSharePlugin::SambaUserSharePlugin(QObject *parent, const QList<QVariant
     m_page->setAttribute(Qt::WA_TranslucentBackground);
     auto widget = new QQuickWidget(m_page.get());
     // Load kdeclarative and set translation domain before setting the source so strings gets translated.
-    KDeclarative::KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(widget->engine());
-    kdeclarative.setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
-    kdeclarative.setupEngine(widget->engine());
-    kdeclarative.setupContext();
+    KDeclarative::KDeclarative::setupEngine(widget->engine());
+    auto i18nContext = new KLocalizedContext(widget->engine());
+    i18nContext->setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
+    widget->engine()->rootContext()->setContextObject(i18nContext);
+
     widget->setResizeMode(QQuickWidget::SizeRootObjectToView);
     widget->setFocusPolicy(Qt::StrongFocus);
     widget->setAttribute(Qt::WA_AlwaysStackOnTop, true);
@@ -212,14 +212,9 @@ SambaUserSharePlugin::SambaUserSharePlugin(QObject *parent, const QList<QVariant
     const QUrl url(QStringLiteral("qrc:/org.kde.filesharing.samba/qml/main.qml"));
     widget->setSource(url);
 
-    // Bump dependency after our 20.12 release to get rid of the if.
-    if (KCoreAddons::version() >= QT_VERSION_CHECK(5, 75, 0)) {
-        properties->setFileSharingPage(m_page.get());
-        if (qEnvironmentVariableIsSet("TEST_FOCUS_SHARE")) {
-            QTimer::singleShot(100, properties, &KPropertiesDialog::showFileSharingPage);
-        }
-    } else { // << 7.75 was broken, hack around it
-        properties->addPage(m_page.get(), i18nc("@title:tab", "Share"));
+    properties->setFileSharingPage(m_page.get());
+    if (qEnvironmentVariableIsSet("TEST_FOCUS_SHARE")) {
+        QTimer::singleShot(100, properties, &KPropertiesDialog::showFileSharingPage);
     }
 
     QTimer::singleShot(0, [this] {
